#
# spec file for package hibernate-types
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global upstream_name hibernate-types-hibernate-types-parent

Name:           hibernate-types
Version:        2.16.2
Release:        3.22
License:        Apache-2.0
Summary:        Hibernate Types adds extra types like JSON, Array, etc
URL:            https://github.com/vladmihalcea/hibernate-types
Group:          Development/Libraries/Java
Source0:        %{url}/archive/refs/tags/%{upstream_name}-%{version}.tar.gz
Patch0:         remove-unused-import.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  java-devel
BuildRequires:  maven-local
BuildRequires:  mvn(ch.qos.logback:logback-classic)
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-databind)
BuildRequires:  mvn(com.fasterxml.jackson.module:jackson-module-jaxb-annotations)
BuildRequires:  mvn(com.google.guava:guava)
BuildRequires:  mvn(jakarta.persistence:jakarta.persistence-api)
BuildRequires:  mvn(org.hibernate.common:hibernate-commons-annotations)
BuildRequires:  mvn(org.hibernate:hibernate-core)
BuildRequires:  mvn(org.postgresql:postgresql)
BuildRequires:  mvn(org.sonatype.oss:oss-parent:pom:)
%if 0%{?rhel}
BuildRequires:  java-1.8.0-openjdk-devel
%endif
Requires:       java
BuildArch:      noarch

%description
Hibernate Types adds extra types like JSON, Array, etc

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}

%prep
%setup -q -n "%{upstream_name}-%{version}"
%patch0 -p1

%pom_remove_plugin -r :maven-toolchains-plugin

%pom_add_dep org.hibernate.common:hibernate-commons-annotations hibernate-types-52
%pom_add_dep jakarta.persistence:jakarta.persistence-api hibernate-types-52

%build
%if 0%{?rhel}
export JAVA_HOME_8=%{_jvmdir}/java-1.8.0-openjdk
%endif
%{mvn_build} -f -- -Dsource=8 -pl hibernate-types-52

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Mon May  1 2023 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Enhanced to build on Enterprise Linux 9.
* Mon Aug 22 2022 Michael Calmer <mc@suse.com>
- Update to version 2.16.2
  * Fix the batch sequence generation for the 2.x version of H2
  * Add support for customizing the JsonType underlying Oracle column type
  * Change JsonBinarySqlTypeDescriptor to bind the JSON object as String
  * Add support for Oracle 21c JSON columns
  * Add support for Hibernate 5.6 in BatchSequenceGenerator
  * Add support for Hibernate 6
  * Create a TypeContributor that registers all supported types
  * Add support for using OffsetDateTime in JSON objects
  * Add support for LocalDateTime[] mappings
  * Add support for LocalDate[] mappings
  * PostgreSQLEnumType#sqlTypes() should always return Types.VARCHAR
  * Add BatchSequenceGenerator
  * Avoid the unnecessary UPDATE for JsonNode entity mappings
  * Parse application.properties and load properties upon initialization
* Tue Jun  7 2022 Michael Calmer <mc@suse.com>
- build with xmvn
  Removed:
  * pom-tweaks.patch
  * build.sh
  Added:
  * remove-unused-import.patch
* Tue Sep 14 2021 Cédric Bosdonnat <cbosdonnat@suse.com>
- Release 2.12.1
- Added patches:
  * pom-tweaks.patch
